==> GEOmetadb_1.4.0.zip: GEOmetadb/doc/GEOmetadb.R <==
###################################################
### chunk number 1: 
###################################################
options(width=55)


###################################################
### chunk number 2: 
###################################################
library(GEOmetadb)


###################################################
### chunk number 3: 
###################################################
getSQLiteFile()


###################################################
### chunk number 4: 
###################################################
file.info('GEOmetadb.sqlite')


###################################################
### chunk number 5: 
###################################################
con <- dbConnect(SQLite(),'GEOmetadb.sqlite')
dbDisconnect(con)


###################################################
### chunk number 6: 
###################################################
con <- dbConnect(SQLite(),'GEOmetadb.sqlite')


###################################################
### chunk number 7: 
###################################################
geo_tables <- dbListTables(con)
geo_tables


###################################################
### chunk number 8: 
###################################################
dbListFields(con,'gse')


###################################################
### chunk number 9: 
###################################################
sqliteQuickSQL(con,'PRAGMA TABLE_INFO(gpl)')


###################################################
### chunk number 10: 
###################################################
rs <- dbGetQuery(con,'select * from gse limit 5')
rs[,1:7]


###################################################
### chunk number 11: 
###################################################
rs <- dbGetQuery(con,paste("select gse,title from gse where",
                           "contributor like '%Sean%Davis%'",sep=" "))
rs


###################################################
### chunk number 12: 
###################################################
rs <- dbGetQuery(con,paste("select gsm,supplementary_file",
                           "from gsm where gpl='GPL96'",
                           "and supplementary_file like '%CEL.gz'"))
dim(rs)


###################################################
### chunk number 13: 
###################################################
rs <- dbGetQuery(con,paste("select gpl.bioc_package,gsm.gpl,",
                           "gsm,gsm.supplementary_file",
                           "from gsm join gpl on gsm.gpl=gpl.gpl",
                           "where gpl.manufacturer='Affymetrix'",
                           "and gsm.supplementary_file like '%CEL.gz' "))
rs[1:5,]


###################################################
### chunk number 14: 
###################################################
getTableCounts <- function(tableName,conn) {
  sql <- sprintf("select count(*) from %s",tableName)
  return(dbGetQuery(conn,sql)[1,1])
}
do.call(rbind,sapply(geo_tables,getTableCounts,con,simplify=FALSE))


###################################################
### chunk number 15: 
###################################################
conversion <- geoConvert('GPL96')


###################################################
### chunk number 16: 
###################################################
lapply(conversion, dim)
conversion$gse[1:5,]
conversion$gsm[1:5,]
conversion$gds[1:5,]
conversion$sMatrix[1:5,]


###################################################
### chunk number 17: 
###################################################
sql <- paste("SELECT DISTINCT gse.title,gse.gse",
             "FROM",
             "  gsm JOIN gse_gsm ON gsm.gsm=gse_gsm.gsm",
             "  JOIN gse ON gse_gsm.gse=gse.gse",
             "  JOIN gse_gpl ON gse_gpl.gse=gse.gse",
             "  JOIN gpl ON gse_gpl.gpl=gpl.gpl",
             "WHERE",
             "  gsm.molecule_ch1 like '%total RNA%' AND",
             "  gse.title LIKE '%breast cancer%' AND",
             "  gpl.organism LIKE '%Homo sapiens%'",sep=" ")
rs <- dbGetQuery(con,sql)
dim(rs)
print(rs[1:5,],right=FALSE)


###################################################
### chunk number 18: 
###################################################
dbDisconnect(con)


###################################################
### chunk number 19: 
###################################################
file.remove('GEOmetadb.sqlite')

==> GEOmetadb_1.10.0.zip: GEOmetadb/doc/GEOmetadb.R <==
###################################################
### chunk number 1: 
###################################################
#line 50 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
options(width=55)


###################################################
### chunk number 2: 
###################################################
#line 58 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
library(GEOmetadb)


###################################################
### chunk number 3: 
###################################################
#line 63 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
getSQLiteFile()


###################################################
### chunk number 4: 
###################################################
#line 71 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
file.info('GEOmetadb.sqlite')


###################################################
### chunk number 5: 
###################################################
#line 76 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
con <- dbConnect(SQLite(),'GEOmetadb.sqlite')
dbDisconnect(con)


###################################################
### chunk number 6: 
###################################################
#line 91 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
con <- dbConnect(SQLite(),'GEOmetadb.sqlite')


###################################################
### chunk number 7: 
###################################################
#line 96 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
geo_tables <- dbListTables(con)
geo_tables


###################################################
### chunk number 8: 
###################################################
#line 102 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
dbListFields(con,'gse')


###################################################
### chunk number 9: 
###################################################
#line 107 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
sqliteQuickSQL(con,'PRAGMA TABLE_INFO(gpl)')


###################################################
### chunk number 10: 
###################################################
#line 114 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
rs <- dbGetQuery(con,'select * from gse limit 5')
rs[,1:7]


###################################################
### chunk number 11: 
###################################################
#line 120 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
rs <- dbGetQuery(con,paste("select gse,title from gse where",
                           "contributor like '%Sean%Davis%'",sep=" "))
rs


###################################################
### chunk number 12: 
###################################################
#line 128 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
rs <- dbGetQuery(con,paste("select gsm,supplementary_file",
                           "from gsm where gpl='GPL96'",
                           "and supplementary_file like '%CEL.gz'"))
dim(rs)


###################################################
### chunk number 13: 
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
rs <- dbGetQuery(con,paste("select gpl.bioc_package,gsm.gpl,",
                           "gsm,gsm.supplementary_file",
                           "from gsm join gpl on gsm.gpl=gpl.gpl",
                           "where gpl.manufacturer='Affymetrix'",
                           "and gsm.supplementary_file like '%CEL.gz' "))
rs[1:5,]


###################################################
### chunk number 14: 
###################################################
#line 147 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
getTableCounts <- function(tableName,conn) {
  sql <- sprintf("select count(*) from %s",tableName)
  return(dbGetQuery(conn,sql)[1,1])
}
do.call(rbind,sapply(geo_tables,getTableCounts,con,simplify=FALSE))


###################################################
### chunk number 15: 
###################################################
#line 161 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
conversion <- geoConvert('GPL96')


###################################################
### chunk number 16: 
###################################################
#line 167 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
lapply(conversion, dim)
conversion$gse[1:5,]
conversion$gsm[1:5,]
conversion$gds[1:5,]
conversion$sMatrix[1:5,]


###################################################
### chunk number 17: 
###################################################
#line 177 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
sql <- paste("SELECT DISTINCT gse.title,gse.gse",
             "FROM",
             "  gsm JOIN gse_gsm ON gsm.gsm=gse_gsm.gsm",
             "  JOIN gse ON gse_gsm.gse=gse.gse",
             "  JOIN gse_gpl ON gse_gpl.gse=gse.gse",
             "  JOIN gpl ON gse_gpl.gpl=gpl.gpl",
             "WHERE",
             "  gsm.molecule_ch1 like '%total RNA%' AND",
             "  gse.title LIKE '%breast cancer%' AND",
             "  gpl.organism LIKE '%Homo sapiens%'",sep=" ")
rs <- dbGetQuery(con,sql)
dim(rs)
print(rs[1:5,],right=FALSE)


###################################################
### chunk number 18: 
###################################################
#line 195 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
dbDisconnect(con)


###################################################
### chunk number 19: 
###################################################
#line 200 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp8tygbW/R.INSTALL43ca2b81/GEOmetadb/inst/doc/GEOmetadb.Rnw"
file.remove('GEOmetadb.sqlite')
